==> hyades.source_1.0.3_20030929_1406.zip: org/eclipse/hyades/models/hierarchy/util/HierarchyResourceSetImpl.java <==
/**********************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v0.5
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v05.html
 *
 * Contributors:
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.hyades.models.hierarchy.util;

import org.eclipse.emf.common.util.URI;
import org.eclipse.emf.common.util.WrappedException;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.resource.Resource;
import org.eclipse.emf.ecore.resource.impl.ResourceSetImpl;


/**
 * This class allows the definition of
 * <p>
 * 1. The singleton to be used by the clients<p>
 * 2. The <code>URIConverter</code> - it must use ZipWorkbenchURIConverter<p>
 * 3. The use of the <code>PerftraceReosurceFactory</code> as the factory for the Agent resources.
 * This factory will handle the definition of keys to be used during the data load process.
 * 4. The Unresolved resource helper
 */
public class HierarchyResourceSetImpl extends ResourceSetImpl {
    //~ Static fields/initializers -----------------------------------------------------------------

    private static HierarchyResourceSetImpl instance;

    //~ Instance fields ----------------------------------------------------------------------------

    private IUnresolvedResourceHelper helper;

    //~ Constructors -------------------------------------------------------------------------------

    protected HierarchyResourceSetImpl() {
        super();
    }

    //~ Methods ------------------------------------------------------------------------------------

    public static HierarchyResourceSetImpl getInstance() {
        if (instance == null) {
            instance = new HierarchyResourceSetImpl();
            instance.setURIConverter(new HierarchyURIConverterImpl());

            //			Resource.Factory xmiResourceFactory = new XMIResourceFactoryImpl();
            Resource.Factory perftraceResourceFactory = new HierarchyResourceFactoryImpl();

            Resource.Factory.Registry.INSTANCE.getExtensionToFactoryMap().put("trcmxmi", perftraceResourceFactory);
            Resource.Factory.Registry.INSTANCE.getExtensionToFactoryMap().put("trcnxmi", perftraceResourceFactory);
            Resource.Factory.Registry.INSTANCE.getExtensionToFactoryMap().put("trcpxmi", perftraceResourceFactory);
            Resource.Factory.Registry.INSTANCE.getExtensionToFactoryMap().put("trcaxmi", perftraceResourceFactory);
        }

        return instance;
    }

    /**
     * If an object is not found with the given uri, load the
     * resource that has it.
     */
    public EObject getObjectAndLoad(URI uri) throws WrappedException {
        EObject obj = null;

        try {
            obj = super.getEObject(uri, true);
        } catch (WrappedException e) {
            if (helper != null) {
                helper.uriException(uri, (Exception) e);
            }

            throw e;
        }

        return obj;
    }

    public IUnresolvedResourceHelper getUnresolvedException() {
        return helper;
    }

    public void setUnresolvedResourceHelper(IUnresolvedResourceHelper helper) {
        this.helper = helper;
    }
}

==> hyades.source_1.2.2_20040226_1349.zip: org/eclipse/hyades/models/hierarchy/util/HierarchyResourceSetImpl.java <==
/**********************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v0.5
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v05.html
 *
 * Contributors:
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.hyades.models.hierarchy.util;

import org.eclipse.emf.common.util.URI;
import org.eclipse.emf.common.util.WrappedException;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.resource.Resource;
import org.eclipse.emf.ecore.resource.impl.ResourceSetImpl;


/**
 * This class allows the definition of
 * <p>
 * 1. The singleton to be used by the clients<p>
 * 2. The <code>URIConverter</code> - it must use ZipWorkbenchURIConverter<p>
 * 3. The use of the <code>PerftraceReosurceFactory</code> as the factory for the Agent resources.
 * This factory will handle the definition of keys to be used during the data load process.
 * 4. The Unresolved resource helper
 */
public class HierarchyResourceSetImpl extends ResourceSetImpl {
    //~ Static fields/initializers -----------------------------------------------------------------

    private static HierarchyResourceSetImpl instance;

    //~ Instance fields ----------------------------------------------------------------------------

    private IUnresolvedResourceHelper helper;

    //~ Constructors -------------------------------------------------------------------------------

    protected HierarchyResourceSetImpl() {
        super();
    }

    //~ Methods ------------------------------------------------------------------------------------

    public static HierarchyResourceSetImpl getInstance() {
        if (instance == null) {
            instance = new HierarchyResourceSetImpl();
            instance.setURIConverter(new HierarchyURIConverterImpl());

            //			Resource.Factory xmiResourceFactory = new XMIResourceFactoryImpl();
            Resource.Factory perftraceResourceFactory = new HierarchyResourceFactoryImpl();

            Resource.Factory.Registry.INSTANCE.getExtensionToFactoryMap().put("trcmxmi", perftraceResourceFactory);
            Resource.Factory.Registry.INSTANCE.getExtensionToFactoryMap().put("trcnxmi", perftraceResourceFactory);
            Resource.Factory.Registry.INSTANCE.getExtensionToFactoryMap().put("trcpxmi", perftraceResourceFactory);
            Resource.Factory.Registry.INSTANCE.getExtensionToFactoryMap().put("trcaxmi", perftraceResourceFactory);
			Resource.Factory.Registry.INSTANCE.getExtensionToFactoryMap().put("corrxmi", perftraceResourceFactory);
			
			Resource.Factory.Registry.INSTANCE.getExtensionToFactoryMap().put("trcadb", new HyadesExtendedResourceFactory());
		}

        return instance;
    }

    /**
     * If an object is not found with the given uri, load the
     * resource that has it.
     */
    public EObject getObjectAndLoad(URI uri) throws WrappedException {
        EObject obj = null;

        try {
            obj = super.getEObject(uri, true);
        } catch (WrappedException e) {
            if (helper != null) {
                helper.uriException(uri, (Exception) e);
            }

            throw e;
        }

        return obj;
    }

    public IUnresolvedResourceHelper getUnresolvedException() {
        return helper;
    }

    public void setUnresolvedResourceHelper(IUnresolvedResourceHelper helper) {
        this.helper = helper;
    }
}
